@@ -121,6 +121,12 @@
 #else
 #  define KGUIADDONS_DEPRECATED_VERSION_6_12(text)
 #endif
+
+#if KGUIADDONS_DEPRECATED_WARNINGS_SINCE >= 0x61600
+#  define KGUIADDONS_DEPRECATED_VERSION_6_22(text) KGUIADDONS_DECL_DEPRECATED_TEXT(text)
+#else
+#  define KGUIADDONS_DEPRECATED_VERSION_6_22(text)
+#endif
 #define KGUIADDONS_DEPRECATED_VERSION_6(minor, text)      KGUIADDONS_DEPRECATED_VERSION_6_##minor(text)
 #define KGUIADDONS_DEPRECATED_VERSION(major, minor, text) KGUIADDONS_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
 #define KGUIADDONS_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) KGUIADDONS_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
